[![Build Status](https://travis-ci.org/jdrudolph/photon.svg?branch=master)](https://travis-ci.org/jdrudolph/photon)

PHOTON is available as part of the [Perseus](https://www.perseus-framework.org) software for proteomics analysis starting from Perseus version 1.6.2.1.

[![Lecture explaining the main concepts behind PHOTON](https://img.youtube.com/vi/JXhZyWA3JIc/0.jpg)](https://www.youtube.com/watch?v=JXhZyWA3JIc)

# Elucidation of Signaling Pathways from Large-Scale Phosphoproteomic Data Using Protein Interaction Networks

Phosphoproteomic experiments typically identify sites within a protein that are differentially phosphorylated between two or more cell states. However, the interpretation of these data is hampered by the lack of methods that can translate site-specific information into global maps of active proteins and signaling networks, especially as the phosphoproteome is often undersampled. Here, we describe PHOTON, a method for interpreting phosphorylation data within their signaling context, as captured by protein-protein interaction networks, to identify active proteins and pathways and pinpoint functional phosphosites. We apply PHOTON to interpret existing and novel phosphoproteomic datasets related to epidermal growth factor and insulin responses. PHOTON substantially outperforms the widely used cutoff approach, providing highly reproducible predictions that are more in line with current biological knowledge. Altogether, PHOTON overcomes the fundamental challenge of delineating signaling pathways from large-scale phosphoproteomic data, thereby enabling translation of environmental cues to downstream cellular responses.

[Pubmed link](https://www.ncbi.nlm.nih.gov/pubmed/28009266)

# Intallation and Tutorial

Follow the [installation instructions](docs/Perseus/installation.md) and
[learn](docs/Perseus/tutorial.md) how to use PHOTON from within Perseus.

# Formulas

Please feel free to ask questions on the code and formulas used. [Here](docs/formulas.ipynb) you can find more detailed information.

# Troubleshooting
Please open an issue [here](https://github.com/jdrudolph/photon/issues), or
contact me directly if you have issues with installing or using PHOTON.

# Licence
If the current [licence](/LICENCE.txt) does not suit your needs,
please contacte me for alternative licencing options.

# Contiribute
Constributions to the code and the documentation of PHOTON are welcome!
